@@ -321,7 +321,8 @@ class Task:
         Raises:
             APIException: If the API returns an error
         """
-        response = list_tasks.sync(
+        # Use sync_detailed to get full response information
+        response_obj = list_tasks.sync_detailed(
             client=self._client,
             page=page,
             page_size=page_size,
@@ -330,19 +331,46 @@ class Task:
             team_id=team_id if team_id is not None else UNSET,
             cluster_id=cluster_id if cluster_id is not None else UNSET,
         )
+        response = response_obj.parsed
 
         if isinstance(response, ErrorResponse):
-            raise handle_api_exception(
+            # Extract error message from ErrorResponse
+            error_msg = "Unknown error"
+            if response.error and response.error != UNSET:
+                error_msg = response.error
+            elif response_obj.content:
+                try:
+                    error_data = json.loads(response_obj.content.decode())
+                    error_msg = error_data.get("error", "Unknown error")
+                except (json.JSONDecodeError, UnicodeDecodeError):
+                    error_msg = response_obj.content.decode(errors="replace")
+            
+            # Check status code to determine exception type
+            status_code = response.code if response.code != UNSET and response.code != 0 else response_obj.status_code.value
+            if status_code == 404:
+                raise NotFoundException(error_msg)
+            
+            # Use handle_api_exception which returns an exception object
+            exception = handle_api_exception(
                 Response(
-                    status_code=HTTPStatus(response.code if response.code != 0 else 400),
-                    content=json.dumps({"error": response.error}).encode() if response.error else b"",
-                    headers={},
+                    status_code=HTTPStatus(status_code),
+                    content=response_obj.content,
+                    headers=response_obj.headers,
                     parsed=None,
                 )
             )
+            raise exception
 
         if response is None:
-            raise APIException("Failed to list tasks: No response from server")
+            # If response is None, try to extract error from raw response
+            error_msg = "No response from server"
+            if response_obj.content:
+                try:
+                    error_data = json.loads(response_obj.content.decode())
+                    error_msg = error_data.get("error", f"HTTP {response_obj.status_code.value}: {response_obj.content.decode()}")
+                except (json.JSONDecodeError, UnicodeDecodeError):
+                    error_msg = f"HTTP {response_obj.status_code.value}: {response_obj.content.decode(errors='replace')}"
+            raise APIException(f"Failed to list tasks: {error_msg}")
 
         return response
 
